summaryrefslogtreecommitdiff
path: root/rpmio
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-04-10 20:00:40 +0000
committerjbj <devnull@localhost>2002-04-10 20:00:40 +0000
commite5a632b26dc0f8df7f552dcf0a07f703db9fd329 (patch)
tree0748845b10f4b3c23064bbc6d940091c27659a12 /rpmio
parentfa1361480f0b9a1154579a21668a249d0bce6126 (diff)
downloadrpm-e5a632b26dc0f8df7f552dcf0a07f703db9fd329.tar.gz
rpm-e5a632b26dc0f8df7f552dcf0a07f703db9fd329.tar.bz2
rpm-e5a632b26dc0f8df7f552dcf0a07f703db9fd329.zip
- beecrypt: add types.h, eliminate need for config.gnu.h.
CVS patchset: 5386 CVS date: 2002/04/10 20:00:40
Diffstat (limited to 'rpmio')
-rw-r--r--rpmio/digest.c2
-rw-r--r--rpmio/rpmio_internal.h4
-rw-r--r--rpmio/rpmpgp.h1
3 files changed, 4 insertions, 3 deletions
diff --git a/rpmio/digest.c b/rpmio/digest.c
index af4f8c02d..53294eaac 100644
--- a/rpmio/digest.c
+++ b/rpmio/digest.c
@@ -3,11 +3,11 @@
*/
#include "system.h"
-#include "rpmio_internal.h"
#include "beecrypt.h"
#include "md5.h"
#include "endianness.h"
#include "fips180.h"
+#include "rpmio_internal.h"
#include "debug.h"
#ifdef SHA_DEBUG
diff --git a/rpmio/rpmpgp.h b/rpmio/rpmpgp.h
index a121aca10..9c63c96d0 100644
--- a/rpmio/rpmpgp.h
+++ b/rpmio/rpmpgp.h
@@ -10,6 +10,7 @@
* Copyright (C) The Internet Society (1998). All Rights Reserved.
*/
+#include "types.h"
#include "base64.h"
#include "dsa.h"
#include "endianness.h"
diff --git a/rpmio/rpmio_internal.h b/rpmio/rpmio_internal.h
index 78838be14..5681ed450 100644
--- a/rpmio/rpmio_internal.h
+++ b/rpmio/rpmio_internal.h
@@ -472,7 +472,7 @@ void fdInitDigest(FD_t fd, pgpHashAlgo hashalgo, int flags)
* Update digest(s) attached to fd.
*/
/*@unused@*/ static inline
-void fdUpdateDigests(FD_t fd, const byte * buf, ssize_t buflen)
+void fdUpdateDigests(FD_t fd, const unsigned char * buf, ssize_t buflen)
/*@modifies fd @*/
{
int i;
@@ -536,7 +536,7 @@ int fdFileno(/*@null@*/ void * cookie)
/**
*/
int rpmioSlurp(const char * fn,
/*@out@*/ const byte ** bp, /*@out@*/ ssize_t * blenp)
/*@globals fileSystem @*/
/*@modifies *bp, *blenp, fileSystem @*/;
@@ -536,7 +536,7 @@ int fdFileno(/*@null@*/ void * cookie)
*/
int rpmioSlurp(const char * fn,
- /*@out@*/ const byte ** bp, /*@out@*/ ssize_t * blenp)
+ /*@out@*/ const unsigned char ** bp, /*@out@*/ ssize_t * blenp)
/*@globals fileSystem @*/
/*@modifies *bp, *blenp, fileSystem @*/;